import pytest


def parametrize(name, params):
    names = name.split(",") if isinstance(name, str) else name

    ids = [f"{key}" for key in params]
    values = [tuple(params[key].values()) for key in params]

    return pytest.mark.parametrize(names, values, ids=ids)
